@@ -8,9 +8,9 @@ use Log::ger;
 use Perinci::Object 'envresmulti';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-08-11'; # DATE
+our $DATE = '2022-08-12'; # DATE
 our $DIST = 'App-GoogleSearchUtils'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our %SPEC;
 
@@ -329,7 +329,7 @@ sub google_search {
             $url = "https://www.google.com/search?num=$num&q=$query_esc&tbm=nws" .
                 ($time_param ? "&$time_param" : "");
         } elsif ($type eq 'map') {
-            return [409, "Can't specify time period for map search"];
+            return [409, "Can't specify time period for map search"] if length $time_param;
             $url = "https://www.google.com/maps/search/$query_esc/";
         } else {
             return [400, "Unknown type '$type'"];
@@ -405,7 +405,7 @@ App::GoogleSearchUtils - CLI utilites related to google searching
 
 =head1 VERSION
 
-This document describes version 0.011 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-08-11.
+This document describes version 0.012 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-08-12.
 
 =head1 SYNOPSIS
 
